package cn.fw.valhalla.domain.query;

import cn.fw.valhalla.common.utils.DateUtil;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;

import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.List;

/**
 * @author : kurisu
 * @className : PublicPoolQueryVO
 * @description : 公共池查询条件
 * @date: 2021-03-30 16:51
 */
@Data
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class PublicPoolQueryVO extends PoolQuery {
    private Integer type;
    private Long brandId;
    private Long seriesId;
    private Long specId;
    private String shopName;
    private Boolean warrantyCard;
    private Boolean maintainCard;
    private List<Long> ignoreCustIds;
    private String createTime;
    private Boolean fromReport;

    public Date getCreateTime1() {
        if (StringUtils.isBlank(createTime)) {
            return null;
        }
        String[] times = createTime.split(",");
        if (StringUtils.isNotBlank(times[0]) && NumberUtils.isDigits(times[0])) {
            LocalDateTime localDateTime = Instant.ofEpochMilli(NumberUtils.toLong(times[0])).atZone(ZoneId.systemDefault()).toLocalDateTime();
            return DateUtil.getBeginInTime(DateUtil.localDateTime2Date(localDateTime));
        }
        return null;
    }

    public Date getCreateTime2() {
        if (StringUtils.isBlank(createTime)) {
            return null;
        }
        String[] times = createTime.split(",");
        if (times.length < TIME_STR_LENGTH) {
            return null;
        }
        if (StringUtils.isNotBlank(times[1]) && NumberUtils.isDigits(times[1])) {
            LocalDateTime localDateTime = Instant.ofEpochMilli(NumberUtils.toLong(times[1])).atZone(ZoneId.systemDefault()).toLocalDateTime();
            return DateUtil.getEndInTime(DateUtil.localDateTime2Date(localDateTime));
        }
        return null;
    }
}
